@@ -3,6 +3,6 @@
                     fields="Version")
   packageStartupMessage(paste0("Package: ", pkgname, ", Version: ", RFver))
   packageStartupMessage("Cause-specific Framework for Competing-risk survival analysis")
-  packageStartupMessage("National Heart & Lung Institute, Imperial College London &")
+  packageStartupMessage("School of Public Heath, Imperial College London &")
   packageStartupMessage("Scientific Computing Group, Sentrana Inc.")
 }
